pub struct DynamicUpdateSlicePlan { /* private fields */ }Expand description
A compiled dynamic-update-slice traversal.
Execution first copies operand into dest, then overwrites the clamped
update window. The plan performs no allocation for ranks at most
RAW_FUSED_RANK_LIMIT.
Implementations
Sourceimpl DynamicUpdateSlicePlan
impl DynamicUpdateSlicePlan
Sourcepub fn compile(
operand_dims: &[usize],
operand_strides: &[isize],
start_dims: &[usize],
start_strides: &[isize],
update_dims: &[usize],
update_strides: &[isize],
dest_dims: &[usize],
dest_strides: &[isize],
) -> Result<Self>
pub fn compile( operand_dims: &[usize], operand_strides: &[isize], start_dims: &[usize], start_strides: &[isize], update_dims: &[usize], update_strides: &[isize], dest_dims: &[usize], dest_strides: &[isize], ) -> Result<Self>
Compile a dynamic-update-slice traversal.
dest_dims must match operand_dims; execution materializes
dest = operand and then overwrites the clamped update window.
Sourcepub fn execute<T, I>(
&self,
dest: &mut RawStridedMut<'_, T>,
operand: &RawStridedRef<'_, T>,
update: &RawStridedRef<'_, T>,
starts: &RawStridedRef<'_, I>,
) -> Result<()>
pub fn execute<T, I>( &self, dest: &mut RawStridedMut<'_, T>, operand: &RawStridedRef<'_, T>, update: &RawStridedRef<'_, T>, starts: &RawStridedRef<'_, I>, ) -> Result<()>
Execute the prepared dynamic-update-slice traversal.