pub struct GatherPlan { /* private fields */ }Expand description
A compiled gather traversal for one value layout, index layout, and output layout.
Implementations
Sourceimpl GatherPlan
impl GatherPlan
Sourcepub fn compile(
operand_dims: &[usize],
operand_strides: &[isize],
index_dims: &[usize],
index_strides: &[isize],
dest_dims: &[usize],
dest_strides: &[isize],
spec: GatherSpec,
) -> Result<Self>
pub fn compile( operand_dims: &[usize], operand_strides: &[isize], index_dims: &[usize], index_strides: &[isize], dest_dims: &[usize], dest_strides: &[isize], spec: GatherSpec, ) -> Result<Self>
Compile a gather plan for fixed operand, index, and destination layouts.
pub fn spec(&self) -> &GatherSpec
pub fn dest_dims(&self) -> &[usize]
Sourcepub fn execute<T, I>(
&self,
dest: &mut RawStridedMut<'_, T>,
operand: &RawStridedRef<'_, T>,
start_indices: &RawStridedRef<'_, I>,
) -> Result<()>
pub fn execute<T, I>( &self, dest: &mut RawStridedMut<'_, T>, operand: &RawStridedRef<'_, T>, start_indices: &RawStridedRef<'_, I>, ) -> Result<()>
Execute the prepared gather traversal.