pub struct ReversePlan { /* private fields */ }Expand description
A compiled reverse traversal over selected axes.
Replay is a strided copy from a negative-stride source view.
Implementations
Sourceimpl ReversePlan
impl ReversePlan
Sourcepub fn compile(
operand_dims: &[usize],
operand_strides: &[isize],
dest_strides: &[isize],
axes: &[usize],
) -> Result<Self>
pub fn compile( operand_dims: &[usize], operand_strides: &[isize], dest_strides: &[isize], axes: &[usize], ) -> Result<Self>
Compile a reverse plan for one operand layout, destination layout, and axis set.
Sourcepub fn execute<T>(
&self,
dest: &mut RawStridedMut<'_, T>,
operand: &RawStridedRef<'_, T>,
) -> Result<()>where
T: Copy + MaybeSendSync,
pub fn execute<T>(
&self,
dest: &mut RawStridedMut<'_, T>,
operand: &RawStridedRef<'_, T>,
) -> Result<()>where
T: Copy + MaybeSendSync,
Execute the prepared reverse traversal.
Sourcepub fn execute_uninit<T>(
&self,
dest: &mut RawStridedMut<'_, MaybeUninit<T>>,
operand: &RawStridedRef<'_, T>,
) -> Result<()>where
T: Copy + MaybeSendSync,
pub fn execute_uninit<T>(
&self,
dest: &mut RawStridedMut<'_, MaybeUninit<T>>,
operand: &RawStridedRef<'_, T>,
) -> Result<()>where
T: Copy + MaybeSendSync,
Execute reverse into storage whose reachable destination elements are uninitialized.