KernelDType

Enum KernelDType 

#[non_exhaustive]
#[repr(u8)]
pub enum KernelDType { F32 = 1, F64 = 2, I32 = 3, I64 = 4, Bool = 5, C32 = 6, C64 = 7, }
Dtypes supported by dtype-erased kernel entry points.

The enum is intentionally limited to the scalar set currently used by the tensor runtime callers. Later FFI layers should map their ABI dtype tags to this enum before dispatching into prepared kernels.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


F32 = 1



F64 = 2



I32 = 3



I64 = 4



Bool = 5



C32 = 6



C64 = 7

Implementations

Source

impl KernelDType

pub const fn label(self) -> &'static str

pub const fn size_of(self) -> usize

pub const fn alignment(self) -> usize

pub const fn requires_valid_byte_values(self) -> bool